unit DBNavPlus;
(*	Modified version of TDBNavigator.  Adds a Captions property so the buttons
	  can have captions too.

  	- Version 1.0 - 11/17/96
		- For Delphi 2.0
 		- This VCL was inspired by an article in "Delphi Delvelopers Journal"
		- This VCL is freeware.
		- William Florac - FITCO
*)

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, DBCtrls, Buttons;

type
  TDBNavPlus = class(TDBNavigator)
  private
    { Private declarations }
		FCaptions: TStrings;
    FLayout: TButtonLayout;
    FSpacing: Integer;
    FMargin: Integer;
  protected
    { Protected declarations }
		procedure SetCaptions(value: TStrings);
    procedure SetLayout(value: TButtonLayout);
    procedure SetSpacing(value: integer);
    procedure SetMargin(value: integer);
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
		destructor Destroy; override;
  published
    { Published declarations }
		property Captions: TStrings read FCaptions write SetCaptions;
		property Layout: TButtonLayout read FLayout write SetLayout default blGlyphTop;
		property Spacing: Integer read FSpacing write SetSpacing default 2;
		property Margin: Integer read FMargin write SetMargin default -1;
		property Font;
  end;

procedure Register;

implementation

{******************************************************************************}
constructor TDBNavPlus.Create(AOwner: TComponent);
var
	x: integer;
begin
	inherited create(AOwner);
  {initialize values}
	FLayout := blGlyphTop;
  FSpacing := 2;
  FMargin := -1;
	FCaptions := TStringList.create;
  FCaptions.Clear;
	FCaptions.Add('First');
	FCaptions.Add('Prior');
	FCaptions.Add('Next');
	FCaptions.Add('Last');
	FCaptions.Add('Insert');
	FCaptions.Add('Delete');
	FCaptions.Add('Edit');
	FCaptions.Add('Accept');
	FCaptions.Add('Undo');
	FCaptions.Add('Refresh');
  {initialize buttons}
	for x := 0 to ComponentCount - 1 do begin
		if Controls[x] is TNavButton then begin
			with Controls[x] as TNavButton do begin
      	if integer(index) < FCaptions.Count
        then Caption := FCaptions[integer(index)]
        else Caption := '?';
        layout := FLayout;
        spacing := FSpacing;
			end;
	  end;
  end;
end; {of Create}

{******************************************************************************}
destructor TDBNavPlus.Destroy;
begin
	FCaptions.Free;
	inherited Destroy;
end; {of destroy}


{******************************************************************************}
procedure TDBNavPlus.SetCaptions(Value: TStrings);
var
	x: integer;
begin
  FCaptions.Assign(Value);
	for x := 0 to ComponentCount - 1 do begin
		if Controls[x] is TNavButton then begin
			with Controls[x] as TNavButton do begin
      	if integer(index) < FCaptions.Count
        then Caption := FCaptions[integer(index)]
        else Caption := '';
			end;
	  end;
  end;

  Invalidate;
end; {of setfieldlist}

procedure TDBNavPlus.SetLayout(value: TButtonLayout);
var
	x: integer;
begin
	FLayout := value;
	for x := 0 to ComponentCount - 1 do begin
		if Controls[x] is TNavButton then begin
			with Controls[x] as TNavButton do Layout := value;
	  end;
  end;
  Invalidate;
end; {of SetLayout}

{******************************************************************************}
procedure TDBNavPlus.SetSpacing(value: integer);
var
	x: integer;
begin
	FSpacing := value;
	for x := 0 to ComponentCount - 1 do begin
		if Controls[x] is TNavButton then begin
			with Controls[x] as TNavButton do Spacing := value;
	  end;
  end;
  Invalidate;
end; {of SetSpacing}

{******************************************************************************}
procedure TDBNavPlus.SetMargin(value: integer);
var
	x: integer;
begin
	FMargin := value;
	for x := 0 to ComponentCount - 1 do begin
		if Controls[x] is TNavButton then begin
			with Controls[x] as TNavButton do margin := value;
	  end;
  end;
  Invalidate;
end; {of SetMargin}


{******************************************************************************}
procedure Register;
begin
  RegisterComponents('Fitco', [TDBNavPlus]);
end; {of Register}

end. {of uniut}
